@@ -60,7 +60,6 @@ use ChemOnomatopist::Util::Graph qw(
     graph_longest_paths_from_vertex
     graph_path_between_vertices
     graph_without_edge_attributes
-    neighbours_at_distance
     subgraph
     tree_branch_positions
     tree_number_of_branches
@@ -99,8 +98,11 @@ sub get_name
 
         require Chemistry::OpenSMILES::Parser;
         my $parser = Chemistry::OpenSMILES::Parser->new;
-        my @graphs = map { ChemOnomatopist::MolecularGraph->new( $_ ) }
-                         $parser->parse( $what );
+        my @graphs = $parser->parse( $what );
+
+        die "separate molecular entities are not handled yet\n" if @graphs > 2;
+
+        @graphs = map { ChemOnomatopist::MolecularGraph->new( $_ ) } @graphs;
 
         # Detecting and naming salts
         if( !$CAUTIOUS && @graphs == 2 &&
@@ -1676,30 +1678,4 @@ sub alkane_chain_name($)
     return IUPAC_numerical_multiplier( $N );
 }
 
-# Implemented according to BBv3 P-92.1.4
-sub order_by_neighbours($$$$)
-{
-    my( $graph, $parent, $A, $B ) = @_;
-
-    my $distance = 0;
-    my @frontA = ( $A );
-    my @frontB = ( $B );
-    while( @frontA || @frontB ) {
-        my $cmp = cmp_arrays( [ reverse sort map { atomic_number( $_ ) } @frontB ],
-                              [ reverse sort map { atomic_number( $_ ) } @frontA ] );
-        return $cmp if $cmp;
-
-        # BBv3 P-92.3: higher atomic numbers appear first
-        $cmp = cmp_arrays( [ reverse sort map { exists $_->{isotope} ? $_->{isotope} : atomic_number( $_ ) } @frontB ],
-                           [ reverse sort map { exists $_->{isotope} ? $_->{isotope} : atomic_number( $_ ) } @frontA ] );
-        return $cmp if $cmp;
-
-        @frontA = neighbours_at_distance( $graph, $A, $distance, set( $parent ) );
-        @frontB = neighbours_at_distance( $graph, $B, $distance, set( $parent ) );
-        $distance++;
-    }
-
-    return 0;
-}
-
 1;
