@@ -6,9 +6,10 @@ package ChemOnomatopist::Util;
 use strict;
 use warnings;
 
+use Chemistry::Isotope qw( isotope_abundance );
 use Exporter;
 use Graph::Undirected;
-use List::Util qw( max min pairs );
+use List::Util qw( first max min pairs );
 use Scalar::Util qw( blessed );
 
 use parent Exporter::;
@@ -17,9 +18,11 @@ our @EXPORT_OK = qw(
     all_max
     all_min
     array_frequencies
+    atomic_number
     circle_permutations
     cmp_arrays
     copy
+    element
     zip
 );
 
@@ -55,6 +58,19 @@ sub array_frequencies(@)
     return %frequencies;
 }
 
+sub atomic_number($)
+{
+    my( $element ) = @_;
+    $element = element( $element ) if ref $element;
+    return unless $element;
+
+    my $abundance = isotope_abundance( $element );
+    my $most_abundant = first { 1 }
+                        sort  { $abundance->{$b} <=> $abundance->{$a} }
+                              keys %$abundance;
+    return $most_abundant + 0;
+}
+
 sub circle_permutations(@)
 {
     my @permutations;
@@ -99,6 +115,24 @@ sub copy($)
     return $copy;
 }
 
+# Derive the chemical element of atom or group representation
+sub element
+{
+    my( $atom_or_group ) = @_;
+    return undef unless ref $atom_or_group;
+
+    if( !blessed $atom_or_group ) {
+        die "unknown value '$atom_or_group' given for element()\n" unless ref $atom_or_group eq 'HASH';
+        return ucfirst $atom_or_group->{symbol};
+    }
+
+    if( $atom_or_group->isa( 'Chemistry::Atom' ) ) { # PerlMol Atom
+        return $atom_or_group->symbol;
+    }
+
+    return $atom_or_group->element;
+}
+
 sub zip(@)
 {
     die "odd input to zip\n" if @_ % 2;
